#ifndef NT2_INCLUDE_CONSTANTS_INVEXP_1_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INVEXP_1_HPP_INCLUDED

#include <nt2/exponential/include/constants/invexp_1.hpp>

#endif
